osx

package
v1.17.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 14, 2026 License: Apache-2.0 Imports: 4 Imported by: 5

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BLines

func BLines(r io.Reader) func(yield func(line []byte) bool)

BLines returns a BLineReader that reads lines from the given reader.

func Check added in v1.15.1

func Check(err error)

Check is a helper function to check the error.

func Errorln

func Errorln(args ...any)

Errorln formats and prints to standard error.

func Fatal

func Fatal(args ...any)

Fatal is equivalent to Errorln followed by os.Exit(1).

func Lines

func Lines(r io.Reader) func(yield func(line string) bool)

Lines returns a LineReader that reads lines from the given reader.

Types

type BLineIter

type BLineIter struct {
	// contains filtered or unexported fields
}

BLineIter is an iterator that reads lines from a reader.

func EnumBLines

func EnumBLines(r io.Reader) BLineIter

EnumBLines returns a BLineIter that reads lines from the given reader.

func (BLineIter) Next

func (it BLineIter) Next() (line []byte, ok bool)

Next reads the next line from the iterator.

type LineIter

type LineIter struct {
	// contains filtered or unexported fields
}

LineIter is an iterator that reads lines from a reader.

func EnumLines

func EnumLines(r io.Reader) LineIter

EnumLines returns a LineIter that reads lines from the given reader.

func (LineIter) Next

func (it LineIter) Next() (line string, ok bool)

Next reads the next line from the iterator.

Jump to