package
Version:
v1.17.3
Opens a new window with list of versions in this module.
Published: Jun 14, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 5
Opens a new window with list of known importers.
Documentation
¶
BLines returns a BLineReader that reads lines from the given reader.
Check is a helper function to check the error.
func Errorln(args ...any)
Errorln formats and prints to standard error.
Fatal is equivalent to Errorln followed by os.Exit(1).
Lines returns a LineReader that reads lines from the given reader.
type BLineIter struct {
}
BLineIter is an iterator that reads lines from a reader.
EnumBLines returns a BLineIter that reads lines from the given reader.
Next reads the next line from the iterator.
LineIter is an iterator that reads lines from a reader.
EnumLines returns a LineIter that reads lines from the given reader.
Next reads the next line from the iterator.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.