osx

package
v1.16.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2026 License: Apache-2.0 Imports: 4 Imported by: 5

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Check added in v1.15.1

func Check(err error)

Check is a helper function to check the error.

func Errorln

func Errorln(args ...any)

Errorln formats and prints to standard error.

func Fatal

func Fatal(args ...any)

Fatal is equivalent to Errorln followed by os.Exit(1).

Types

type BLineIter

type BLineIter struct {
	// contains filtered or unexported fields
}

BLineIter is an iterator that reads lines from a reader.

func EnumBLines

func EnumBLines(r io.Reader) BLineIter

EnumBLines returns a BLineIter that reads lines from the given reader.

func (BLineIter) Next

func (it BLineIter) Next() (line []byte, ok bool)

Next reads the next line from the iterator.

type BLineReader

type BLineReader struct {
	// contains filtered or unexported fields
}

BLineReader is a wrapper around io.Reader that provides a method to read lines.

func BLines

func BLines(r io.Reader) BLineReader

BLines returns a BLineReader that reads lines from the given reader.

func (BLineReader) XGo_Enum added in v1.16.0

func (p BLineReader) XGo_Enum() BLineIter

type LineIter

type LineIter struct {
	// contains filtered or unexported fields
}

LineIter is an iterator that reads lines from a reader.

func EnumLines

func EnumLines(r io.Reader) LineIter

EnumLines returns a LineIter that reads lines from the given reader.

func (LineIter) Next

func (it LineIter) Next() (line string, ok bool)

Next reads the next line from the iterator.

type LineReader

type LineReader struct {
	// contains filtered or unexported fields
}

LineReader is a wrapper around io.Reader that provides a method to read lines.

func Lines

func Lines(r io.Reader) LineReader

Lines returns a LineReader that reads lines from the given reader.

func (LineReader) XGo_Enum added in v1.16.0

func (p LineReader) XGo_Enum() LineIter

Jump to