Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BLineIter ¶
type BLineIter struct {
// contains filtered or unexported fields
}
BLineIter is an iterator that reads lines from a reader.
func EnumBLines ¶
EnumBLines returns a BLineIter that reads lines from the given reader.
type BLineReader ¶
type BLineReader struct {
// contains filtered or unexported fields
}
BLineReader is a wrapper around io.Reader that provides a method to read lines.
func BLines ¶
func BLines(r io.Reader) BLineReader
BLines returns a BLineReader that reads lines from the given reader.
func (BLineReader) XGo_Enum ¶ added in v1.16.0
func (p BLineReader) XGo_Enum() BLineIter
type LineIter ¶
type LineIter struct {
// contains filtered or unexported fields
}
LineIter is an iterator that reads lines from a reader.
type LineReader ¶
type LineReader struct {
// contains filtered or unexported fields
}
LineReader is a wrapper around io.Reader that provides a method to read lines.
func Lines ¶
func Lines(r io.Reader) LineReader
Lines returns a LineReader that reads lines from the given reader.
func (LineReader) XGo_Enum ¶ added in v1.16.0
func (p LineReader) XGo_Enum() LineIter
Click to show internal directories.
Click to hide internal directories.